@@ -27,7 +27,7 @@
 
 #define MAXSTRING 256
 
-#define HEADER_STRING "GNU Unifont 8.0" /* to be printed as chart title */
+#define HEADER_STRING "GNU Unifont 9.0.02" /* to be printed as chart title */
 
 /*
    Stylistic Note:
